@@ -21,7 +21,7 @@ import traceback
 import warnings
 from contextlib import contextmanager
 from threading import RLock
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, cast
 from urllib.parse import quote_plus, urlencode
 
 import jaydebeapi
@@ -32,7 +32,11 @@ from airflow.exceptions import AirflowException
 from airflow.providers.common.sql.hooks.sql import DbApiHook
 
 if TYPE_CHECKING:
-    from airflow.models.connection import Connection
+    if TYPE_CHECKING:
+        try:
+            from airflow.sdk import Connection
+        except ImportError:
+            from airflow.models.connection import Connection  # type: ignore[assignment]
 
 
 @contextmanager
@@ -186,9 +190,9 @@ class JdbcHook(DbApiHook):
 
     def get_conn(self) -> jaydebeapi.Connection:
         conn: Connection = self.connection
-        host: str = conn.host
-        login: str = conn.login
-        psw: str = conn.password
+        host: str = cast("str", conn.host)
+        login: str = cast("str", conn.login)
+        psw: str = cast("str", conn.password)
 
         with self.lock:
             conn = jaydebeapi.connect(
@@ -229,7 +233,7 @@ class JdbcHook(DbApiHook):
 
         scheme = extra.get("sqlalchemy_scheme")
         if not scheme:
-            return conn.host
+            return cast("str", conn.host)
 
         driver = extra.get("sqlalchemy_driver")
         uri_prefix = f"{scheme}+{driver}" if driver else scheme
